==> nextcloud-27.1.5.tgz: nextcloud/apps/theming/l10n/zh_TW.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "指定的名稱太長",
    "The given web address is too long" : "提供的網址太長",
    "The given web address is not a valid URL" : "指定的網址不是有效的 URL",
    "The given legal notice address is too long" : "指定的法律聲明網址太長",
    "The given legal notice address is not a valid URL" : "指定的法律聲明網址不是有效的 URL",
    "The given privacy policy address is too long" : "指定的隱私權政策網址太長",
    "The given privacy policy address is not a valid URL" : "指定的隱私權政策網址不是有效的 URL",
    "The given slogan is too long" : "指定的標語太長",
    "The given color is invalid" : "指定的顏色無效",
    "Disable-user-theming should be true or false" : "Disable-user-theming 應該是 true 或 false",
    "Saved" : "已儲存",
    "Invalid app given" : "指定了無效的應用程式",
    "Invalid type for setting \"defaultApp\" given" : "設定「defaultApp」指定了無效的類型",
    "Invalid setting key" : "無效的設定鍵",
    "The file was uploaded" : "檔案已上傳",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 參數的設定",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
    "The file was only partially uploaded" : "檔案僅部份上傳",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Could not write file to disk" : "無法將檔案寫入硬碟",
    "A PHP extension stopped the file upload" : "一個 PHP 擴充功能終止檔案的上傳",
    "No file uploaded" : "未上傳檔案",
    "Failed to clean up the old administration theming images folder" : "無法清除舊的管理佈景主題影像資料夾",
    "Failed to clean up the old administration image folder" : "清除舊的管理影像資料夾失敗",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "您已經在使用自訂佈景主題。佈景主題應用程式設定可能會被覆寫。",
    "Theming" : "佈景主題",
    "Appearance and accessibility" : "外觀與無障礙存取",
    "Dark theme with high contrast mode" : "有高對比模式的深色主題",
    "Enable dark high contrast mode" : "啟用深色高對比模式",
    "Similar to the high contrast mode, but with dark colours." : "類似於高對比模式，但顏色較深。",
    "Dark theme" : "深色主題",
    "Enable dark theme" : "啟用深色主題",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "透過降低整體光度與亮度來舒緩您的眼睛的深色主題。",
    "System default theme" : "系統預設佈景主題",
    "Enable the system default" : "啟用系統預設值",
    "Using the default system appearance." : "使用預設的系統外觀。",
    "Dyslexia font" : "閱讀障礙字型",
    "Enable dyslexia font" : "啟用閱讀障礙字型",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic 是一種免費的字型，目的在降低因拼音文字閱讀障礙引起的一些常見閱讀錯誤。",
    "High contrast mode" : "高對比度模式",
    "Enable high contrast mode" : "開啟高對比度模式",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "高對比度模式會降低介面品質，但會提高清晰度，有助您瀏覽。",
    "Light theme" : "淺色佈景主題",
    "Enable the default light theme" : "啟用預設的淺色佈景主題",
    "The default light appearance." : "預設的淺色外觀。",
    "Legal notice" : "法律聲明",
    "Privacy policy" : "隱私權政策",
    "Adjust the Nextcloud theme" : "調整 Nextcloud 佈景主題",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "使用佈景主題來客製化網頁界面和客戶端程式的外觀（並非所有客戶端程式都支援佈景主題），外觀將會套用至所有使用者。",
    "Advanced options" : "進階選項",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "安裝支援 SVG 圖片的 PHP ImageMagick 擴充元件，以上傳的圖示與顏色為基礎生成 favicons。",
    "Name" : "名稱",
    "Web link" : "網路連結",
    "a safe home for all your data" : "您資料的安全屋",
    "Slogan" : "標語",
    "Color" : "顏色",
    "Logo" : "Logo",
    "Upload new logo" : "上傳新的 Logo",
    "Background and login image" : "背景與登入圖片",
    "Upload new background and login image" : "上傳新的背景與登入圖片",
    "Legal notice link" : "法律聲明連結",
    "Privacy policy link" : "隱私權政策連結",
    "Header logo" : "頁首圖示",
    "Upload new header logo" : "上傳新的頁首圖示",
    "Favicon" : "Favicon",
    "Upload new favicon" : "上傳新 favicon",
    "User settings" : "使用者設定",
    "Disable user theming" : "停用使用者佈景主題",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "雖然您可以選取並自訂您的站台，但使用者仍可以變更他們自己的背景與顏色。若您想要強制執行您的自訂，您可以將其開啟。",
    "Background" : "背景圖片",
    "Customization has been disabled by your administrator" : "您的管理員已停用自訂",
    "Set a custom background" : "設定自訂背景",
    "Keyboard shortcuts" : "鍵盤快捷鍵",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "在某些情況下，鍵盤快捷鍵可能會干擾無障礙工具。為了可以正確地將焦點置於您的工具，您可以在此處停用所有鍵盤快捷鍵。這也會停用應用程式中的所有可用的快捷鍵。",
    "Disable all keyboard shortcuts" : "停用所有鍵盤快捷鍵",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "我們非常重視無障礙存取。我們遵循網路標準，並透過檢查來確保所有內容皆可在沒有滑鼠或輔助軟體（例如螢幕閱讀器）的情況下使用。我們目標是能達到{guidelines}網頁內容可及性指引{linkend} 2.1 版的 AA 等級，加上高對比度主題甚至還能到 AAA 等級。",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "如果您發現任何一個問題，請不要猶豫並請在{issuetracker}我們的問題追蹤系統{linkend}回報。而如果您想參與，歡迎加入{designteam}我們的設計團隊{linkend}！",
    "Current selected app: {app}, position {position} of {total}" : "目前選取的應用程式：{app}、位置為 {position}，共 {total}",
    "Move up" : "向上移動",
    "Move down" : "向下移動",
    "Custom background" : "自訂背景",
    "Default background" : "預設背景",
    "Change color" : "變更顏色",
    "No background" : "無背景",
    "Select a background from your files" : "從您的檔案中選取背景",
    "Select background" : "選取背景",
    "No background has been selected" : "未選取背景",
    "Theme selection is enforced" : "強制佈景主題選取",
    "Navigation bar settings" : "導覽列設定",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "您可以設定用於導覽列的應用程式順序。第一個條目將會是預設的應用程式，會在登入後或點擊標誌時開啟。",
    "The default app can not be changed because it was configured by the administrator." : "預設的應用程式無法變更，因為其由管理員設定。",
    "The app order was changed, to see it in action you have to reload the page." : "應用程式順序已變更，要檢視其實際狀況，您必須重新載入頁面。",
    "Reset default app order" : "重設預設的應用程式順序",
    "Could not set the app order" : "無法設定應用程式順序",
    "Could not reset the app order" : "無法重設應用程式順序",
    "Default app" : "預設應用程式",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "預設應用程式是，例如登入後或點擊選單中的標誌時開啟的應用程式。",
    "Use custom default app" : "使用自訂的預設應用程式",
    "Global default app" : "全域預設應用程式",
    "Global default apps" : "全域預設應用程式",
    "Default app priority" : "預設應用程式優先程度",
    "If an app is not enabled for a user, the next app with lower priority is used." : "若未對某個使用者啟用某個應用程式，則使用下一個優先程度較低的應用程式。",
    "Could not set global default apps" : "無法設定全域預設應用程式",
    "Select a custom color" : "選取自訂色彩",
    "Reset to default" : "恢復預設值",
    "Upload" : "上傳",
    "Remove background image" : "移除背景圖片"
},
"nplurals=1; plural=0;");

==> nextcloud-27.1.6.tgz: nextcloud/apps/theming/l10n/zh_TW.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "指定的名稱太長",
    "The given web address is too long" : "提供的網址太長",
    "The given web address is not a valid URL" : "指定的網址不是有效的 URL",
    "The given legal notice address is too long" : "指定的法律聲明網址太長",
    "The given legal notice address is not a valid URL" : "指定的法律聲明網址不是有效的 URL",
    "The given privacy policy address is too long" : "指定的隱私權政策網址太長",
    "The given privacy policy address is not a valid URL" : "指定的隱私權政策網址不是有效的 URL",
    "The given slogan is too long" : "指定的標語太長",
    "The given color is invalid" : "指定的顏色無效",
    "Disable-user-theming should be true or false" : "Disable-user-theming 應該是 true 或 false",
    "Saved" : "已儲存",
    "Invalid app given" : "指定了無效的應用程式",
    "Invalid type for setting \"defaultApp\" given" : "設定「defaultApp」指定了無效的類型",
    "Invalid setting key" : "無效的設定鍵",
    "The file was uploaded" : "檔案已上傳",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 參數的設定",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
    "The file was only partially uploaded" : "檔案僅部份上傳",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Could not write file to disk" : "無法將檔案寫入硬碟",
    "A PHP extension stopped the file upload" : "一個 PHP 擴充功能終止檔案的上傳",
    "No file uploaded" : "未上傳檔案",
    "Failed to clean up the old administration theming images folder" : "無法清除舊的管理佈景主題影像資料夾",
    "Failed to clean up the old administration image folder" : "清除舊的管理影像資料夾失敗",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "您已經在使用自訂佈景主題。佈景主題應用程式設定可能會被覆寫。",
    "Theming" : "佈景主題",
    "Appearance and accessibility" : "外觀與無障礙存取",
    "PHP Imagick module" : "PHP Imagick 模組",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "雖然已啟用佈景主題應用程式，但並未啟用 PHP 模組「imagick」。為了讓 favicon 產生流程正常運作，您必須安裝並啟用此模組。",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "此站台的 PHP 模組「imagick」不支援 SVG。為了更好的相容性，建議安裝它。",
    "Dark theme with high contrast mode" : "有高對比模式的深色主題",
    "Enable dark high contrast mode" : "啟用深色高對比模式",
    "Similar to the high contrast mode, but with dark colours." : "類似於高對比模式，但顏色較深。",
    "Dark theme" : "深色主題",
    "Enable dark theme" : "啟用深色主題",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "透過降低整體光度與亮度來舒緩您的眼睛的深色主題。",
    "System default theme" : "系統預設佈景主題",
    "Enable the system default" : "啟用系統預設值",
    "Using the default system appearance." : "使用預設的系統外觀。",
    "Dyslexia font" : "閱讀障礙字型",
    "Enable dyslexia font" : "啟用閱讀障礙字型",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic 是一種免費的字型，目的在降低因拼音文字閱讀障礙引起的一些常見閱讀錯誤。",
    "High contrast mode" : "高對比度模式",
    "Enable high contrast mode" : "開啟高對比度模式",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "高對比度模式會降低介面品質，但會提高清晰度，有助您瀏覽。",
    "Light theme" : "淺色佈景主題",
    "Enable the default light theme" : "啟用預設的淺色佈景主題",
    "The default light appearance." : "預設的淺色外觀。",
    "Legal notice" : "法律聲明",
    "Privacy policy" : "隱私權政策",
    "Adjust the Nextcloud theme" : "調整 Nextcloud 佈景主題",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "使用佈景主題來客製化網頁界面和客戶端程式的外觀（並非所有客戶端程式都支援佈景主題），外觀將會套用至所有使用者。",
    "Advanced options" : "進階選項",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "安裝支援 SVG 圖片的 PHP ImageMagick 擴充元件，以上傳的圖示與顏色為基礎生成 favicons。",
    "Name" : "名稱",
    "Web link" : "網路連結",
    "a safe home for all your data" : "您資料的安全屋",
    "Slogan" : "標語",
    "Color" : "顏色",
    "Logo" : "Logo",
    "Upload new logo" : "上傳新的 Logo",
    "Background and login image" : "背景與登入圖片",
    "Upload new background and login image" : "上傳新的背景與登入圖片",
    "Legal notice link" : "法律聲明連結",
    "Privacy policy link" : "隱私權政策連結",
    "Header logo" : "頁首圖示",
    "Upload new header logo" : "上傳新的頁首圖示",
    "Favicon" : "Favicon",
    "Upload new favicon" : "上傳新 favicon",
    "User settings" : "使用者設定",
    "Disable user theming" : "停用使用者佈景主題",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "雖然您可以選取並自訂您的站台，但使用者仍可以變更他們自己的背景與顏色。若您想要強制執行您的自訂，您可以將其開啟。",
    "Appearance and accessibility settings" : "外觀與無障礙存取設定",
    "Background" : "背景圖片",
    "Customization has been disabled by your administrator" : "您的管理員已停用自訂",
    "Set a custom background" : "設定自訂背景",
    "Keyboard shortcuts" : "鍵盤快捷鍵",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "在某些情況下，鍵盤快捷鍵可能會干擾無障礙工具。為了可以正確地將焦點置於您的工具，您可以在此處停用所有鍵盤快捷鍵。這也會停用應用程式中的所有可用的快捷鍵。",
    "Disable all keyboard shortcuts" : "停用所有鍵盤快捷鍵",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "我們非常重視無障礙存取。我們遵循網路標準，並透過檢查來確保所有內容皆可在沒有滑鼠或輔助軟體（例如螢幕閱讀器）的情況下使用。我們目標是能達到{guidelines}網頁內容可及性指引{linkend} 2.1 版的 AA 等級，加上高對比度主題甚至還能到 AAA 等級。",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "如果您發現任何一個問題，請不要猶豫並請在{issuetracker}我們的問題追蹤系統{linkend}回報。而如果您想參與，歡迎加入{designteam}我們的設計團隊{linkend}！",
    "Current selected app: {app}, position {position} of {total}" : "目前選取的應用程式：{app}、位置為 {position}，共 {total}",
    "Move up" : "向上移動",
    "Move down" : "向下移動",
    "Custom background" : "自訂背景",
    "Default background" : "預設背景",
    "Change color" : "變更顏色",
    "No background" : "無背景",
    "Select a background from your files" : "從您的檔案中選取背景",
    "Select background" : "選取背景",
    "No background has been selected" : "未選取背景",
    "Theme selection is enforced" : "強制佈景主題選取",
    "Navigation bar settings" : "導覽列設定",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "您可以設定用於導覽列的應用程式順序。第一個條目將會是預設的應用程式，會在登入後或點擊標誌時開啟。",
    "The default app can not be changed because it was configured by the administrator." : "預設的應用程式無法變更，因為其由管理員設定。",
    "The app order was changed, to see it in action you have to reload the page." : "應用程式順序已變更，要檢視其實際狀況，您必須重新載入頁面。",
    "Reset default app order" : "重設預設的應用程式順序",
    "Could not set the app order" : "無法設定應用程式順序",
    "Could not reset the app order" : "無法重設應用程式順序",
    "Default app" : "預設應用程式",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "預設應用程式是，例如登入後或點擊選單中的標誌時開啟的應用程式。",
    "Use custom default app" : "使用自訂的預設應用程式",
    "Global default app" : "全域預設應用程式",
    "Global default apps" : "全域預設應用程式",
    "Default app priority" : "預設應用程式優先程度",
    "If an app is not enabled for a user, the next app with lower priority is used." : "若未對某個使用者啟用某個應用程式，則使用下一個優先程度較低的應用程式。",
    "Could not set global default apps" : "無法設定全域預設應用程式",
    "Select a custom color" : "選取自訂色彩",
    "Reset to default" : "恢復預設值",
    "Upload" : "上傳",
    "Remove background image" : "移除背景圖片"
},
"nplurals=1; plural=0;");
